<?php

/**
 * BuddyPress Media
 *
 * The main BuddyPress Media Class. This is where everything starts.
 *
 * @package BuddyPressMedia
 * @subpackage Main
 *
 * @author Saurabh Shukla <saurabh.shukla@rtcamp.com>
 * @author Gagandeep Singh <gagandeep.singh@rtcamp.com>
 * @author Joshua Abenazer <joshua.abenazer@rtcamp.com>
 */
if (!defined('ABSPATH'))
    exit;

class BuddyPressMedia {

    public $text_domain = 'buddypress-media';
    public $options;
    public $support_email = 'support@rtcamp.com';
    public $support_url = 'http://rtcamp.com/support/forum/buddypress-media/';
    public $query;
    public $albums_query;
    public $count = null;
    public $posts_per_page = 10;
    public $activity_types = array(
        'media_upload',
        'album_updated',
        'album_created'
    );
    public $hidden_activity_cache = array();
    public $loader;
    public $group_loader;

    public function __construct() {
        $this->constants();
        $this->excerpt_lengths();
        add_action('admin_notices', array($this, 'bp_exists'));
        /**
         * Activating the plugin!
         */
        register_activation_hook(__FILE__, array($this, 'activate'));

        /**
         * And hooking it to BuddyPress
         */
        add_action('bp_include', array($this, 'init'));
        add_action('widgets_init', array($this, 'widgets_init'), 1);
		add_action('plugins_loaded',array($this,'load_translation'));
		global $bp_media_counter;
		$bp_media_counter = 0;
    }

    public function bp_exists() {
        if (!class_exists('BuddyPress')) {
            echo '<div class="error">
       <p><strong>' . __('BuddyPress is not installed.', $this->text_domain) . '</strong></p>
       <p>' . sprintf(__('To use BuddyPress Media, <a href="%s" target="_blank">BuddyPress</a> must be installed first.', $this->text_domain), 'http://wordpress.org/extend/plugins/buddypress/') . '</p>
    </div>';
        }
    }

    public function get_option() {
        $this->options = bp_get_option('bp_media_options');
    }

    public function constants() {
        /* Text domain */
        if (!defined('BP_MEDIA_TXT_DOMAIN'))
            define('BP_MEDIA_TXT_DOMAIN', $this->text_domain);

        /* If the plugin is installed. */
        if (!defined('BP_MEDIA_IS_INSTALLED'))
            define('BP_MEDIA_IS_INSTALLED', 1);

        /* Current Version. */
        if (!defined('BP_MEDIA_VERSION'))
            define('BP_MEDIA_VERSION', '2.4');

        /* Required Version  */
        if (!defined('BP_MEDIA_REQUIRED_BP'))
            define('BP_MEDIA_REQUIRED_BP', '1.6.2');

        /* Database Version */
        if (!defined('BP_MEDIA_DB_VERSION'))
            define('BP_MEDIA_DB_VERSION', '2.1');

        /**
          /* A constant to Active Collab API Assignee ID
          if ( ! defined( 'BP_MEDIA_AC_API_ASSIGNEE_ID' ) )
          define( 'BP_MEDIA_AC_API_ASSIGNEE_ID', '5' );

          /* A constant to Active Collab API Assignee ID
          if ( ! defined( 'BP_MEDIA_AC_API_LABEL_ID' ) )
          define( 'BP_MEDIA_AC_API_LABEL_ID', '1' );

          /* A constant to Active Collab API priority
          if ( ! defined( 'BP_MEDIA_AC_API_PRIORITY' ) )
          define( 'BP_MEDIA_AC_API_PRIORITY', '2' );

          /* A constant to Active Collab API priority
          if ( ! defined( 'BP_MEDIA_AC_API_CATEGORY_ID' ) )
          define( 'BP_MEDIA_AC_API_CATEGORY_ID', '224' );
         */
        /* Slug Constants */
        if (!defined('BP_MEDIA_SLUG'))
            define('BP_MEDIA_SLUG', 'media');

        if (!defined('BP_MEDIA_UPLOAD_SLUG'))
            define('BP_MEDIA_UPLOAD_SLUG', 'upload');

        if (!defined('BP_MEDIA_DELETE_SLUG'))
            define('BP_MEDIA_DELETE_SLUG', 'delete');

        if (!defined('BP_MEDIA_IMAGES_SLUG'))
            define('BP_MEDIA_IMAGES_SLUG', 'photos');

        if (!defined('BP_MEDIA_IMAGES_ENTRY_SLUG'))
            define('BP_MEDIA_IMAGES_ENTRY_SLUG', 'view');

        if (!defined('BP_MEDIA_IMAGES_EDIT_SLUG'))
            define('BP_MEDIA_IMAGES_EDIT_SLUG', 'edit');

        if (!defined('BP_MEDIA_VIDEOS_SLUG'))
            define('BP_MEDIA_VIDEOS_SLUG', 'videos');

        if (!defined('BP_MEDIA_VIDEOS_ENTRY_SLUG'))
            define('BP_MEDIA_VIDEOS_ENTRY_SLUG', 'watch');

        if (!defined('BP_MEDIA_VIDEOS_EDIT_SLUG'))
            define('BP_MEDIA_VIDEOS_EDIT_SLUG', 'edit');

        if (!defined('BP_MEDIA_AUDIO_SLUG'))
            define('BP_MEDIA_AUDIO_SLUG', 'music');

        if (!defined('BP_MEDIA_AUDIO_ENTRY_SLUG'))
            define('BP_MEDIA_AUDIO_ENTRY_SLUG', 'listen');

        if (!defined('BP_MEDIA_AUDIO_EDIT_SLUG'))
            define('BP_MEDIA_AUDIO_EDIT_SLUG', 'edit');

        if (!defined('BP_MEDIA_ALBUMS_SLUG'))
            define('BP_MEDIA_ALBUMS_SLUG', 'albums');

        if (!defined('BP_MEDIA_ALBUMS_ENTRY_SLUG'))
            define('BP_MEDIA_ALBUMS_ENTRY_SLUG', 'list');

        if (!defined('BP_MEDIA_ALBUMS_EDIT_SLUG'))
            define('BP_MEDIA_ALBUMS_EDIT_SLUG', 'edit');

        /* Labels loaded via text domain, can be translated */
        if (!defined('BP_MEDIA_LABEL'))
            define('BP_MEDIA_LABEL', __('Media', $this->text_domain));

        if (!defined('BP_MEDIA_LABEL_SINGULAR'))
            define('BP_MEDIA_LABEL_SINGULAR', __('Media', $this->text_domain));

        if (!defined('BP_MEDIA_IMAGES_LABEL'))
            define('BP_MEDIA_IMAGES_LABEL', __('Photos', $this->text_domain));

        if (!defined('BP_MEDIA_IMAGES_LABEL_SINGULAR'))
            define('BP_MEDIA_IMAGES_LABEL_SINGULAR', __('Photo', $this->text_domain));

        if (!defined('BP_MEDIA_VIDEOS_LABEL'))
            define('BP_MEDIA_VIDEOS_LABEL', __('Videos', $this->text_domain));

        if (!defined('BP_MEDIA_VIDEOS_LABEL_SINGULAR'))
            define('BP_MEDIA_VIDEOS_LABEL_SINGULAR', __('Video', $this->text_domain));

        if (!defined('BP_MEDIA_AUDIO_LABEL'))
            define('BP_MEDIA_AUDIO_LABEL', __('Music', $this->text_domain));

        if (!defined('BP_MEDIA_AUDIO_LABEL_SINGULAR'))
            define('BP_MEDIA_AUDIO_LABEL_SINGULAR', __('Music', $this->text_domain));

        if (!defined('BP_MEDIA_ALBUMS_LABEL'))
            define('BP_MEDIA_ALBUMS_LABEL', __('Albums', $this->text_domain));

        if (!defined('BP_MEDIA_ALBUMS_LABEL_SINGULAR'))
            define('BP_MEDIA_ALBUMS_LABEL_SINGULAR', __('Album', $this->text_domain));

        if (!defined('BP_MEDIAUPLOAD_LABEL'))
            define('BP_MEDIA_UPLOAD_LABEL', __('Upload', $this->text_domain));

        if (!defined('BP_MEDIA_TMP_DIR'))
            define('BP_MEDIA_TMP_DIR', WP_CONTENT_DIR . '/bp-media-temp');

        if (!defined('BP_MEDIA_SUPPORT_EMAIL'))
            define('BP_MEDIA_SUPPORT_EMAIL', $this->support_email);
    }

    function init() {
        $this->get_option();

        if (defined('BP_VERSION') && version_compare(BP_VERSION, BP_MEDIA_REQUIRED_BP, '>=')) {
            add_filter('plugin_action_links', array($this, 'settings_link'), 10, 2);
            $this->loader = new BPMediaLoader();
            $this->group_loader = new BPMediaGroup();
            new BPMediaFilters();
            new BPMediaActions();
            new BPMediaFunction();
        }


        add_action('admin_notices', array($this, 'admin_notice'));
        global $bp_media_admin;
        $bp_media_admin = new BPMediaAdmin();
    }

	static function load_translation(){
		load_plugin_textdomain(BP_MEDIA_TXT_DOMAIN, false,  basename(BP_MEDIA_PATH).'/languages/');
	}

    function settings_link($links, $file) {
        /* create link */
        $plugin_name = plugin_basename(BP_MEDIA_PATH.'index.php');
        $admin_link = $this->get_admin_url(add_query_arg(array('page' => 'bp-media-settings'), 'admin.php'));
        if ($file == $plugin_name) {
            array_unshift(
                    $links, sprintf('<a href="%s">%s</a>', $admin_link, __('Settings', $this->text_domain))
            );
        }
        return $links;
    }

    function media_sizes() {
        $def_sizes = array(
            'activity_image' => array(
                'width' => 320,
                'height' => 240
            ),
            'activity_video' => array(
                'width' => 320,
                'height' => 240
            ),
            'activity_audio' => array(
                'width' => 320,
            ),
            'single_image' => array(
                'width' => 800,
                'height' => 0
            ),
            'single_video' => array(
                'width' => 640,
                'height' => 480
            ),
            'single_audio' => array(
                'width' => 640,
            ),
        );

        return apply_filters('bpm_media_sizes', $def_sizes);
    }

    function excerpt_lengths() {
        global $bp_media_default_excerpts;
        $def_excerpt = array(
            'single_entry_title' => 100,
            'single_entry_description' => 500,
            'activity_entry_title' => 50,
            'activity_entry_description' => 500
        );

        $bp_media_default_excerpts = apply_filters('bpm_excerpt_lengths', $def_excerpt);
    }

    public function admin_notice() {
        global $current_user;
        $user_id = $current_user->ID;
        if (isset($_GET['bp_media_nag_ignore']) && '0' == $_GET['bp_media_nag_ignore']) {
            add_user_meta($user_id, 'bp_media_ignore_notice', 'true', true);
        }
        /* Check that the user hasn't already clicked to ignore the message */
        if (!get_user_meta($user_id, 'bp_media_ignore_notice')) {
            if (defined('BP_VERSION')) {
                if (version_compare(BP_VERSION, BP_MEDIA_REQUIRED_BP, '<')) {
                    echo '<div class="error"><p>';
                    printf(__('The BuddyPress version installed is an older version and is not supported, please update BuddyPress to use BuddyPress Media Plugin.<a class="alignright" href="%1$s">X</a>', $this->text_domain), '?bp_media_nag_ignore=0');
                    echo "</p></div>";
                }
            } else {
                echo '<div class="error"><p>';
                printf(__('You have not installed BuddyPress. Please install latest version of BuddyPress to use BuddyPress Media plugin.<a class="alignright" href="%1$s">X</a>', $this->text_domain), '?bp_media_nag_ignore=0');
                echo "</p></div>";
            }
        }
    }

    public function activate() {
        $bpmquery = new WP_Query(array('post_type' => 'bp_media', 'posts_per_page' => 1));
        if ($bpmquery->found_posts > 0) {
            update_site_option('bp_media_db_version', '1.0');
        } else {
            switch (get_site_option('bp_media_db_version', false, false)) {
                case '2.0':
                    break;
                default:
                    update_site_option('bp_media_db_version', BP_MEDIA_DB_VERSION);
            }
        }
    }

    function get_admin_url($path = '', $scheme = 'admin') {

        // Links belong in network admin
        if (is_multisite())
            $url = network_admin_url($path, $scheme);

        // Links belong in site admin
        else
            $url = admin_url($path, $scheme);

        return $url;
    }

    function widgets_init() {
        register_widget('BPMediaRecentMedia');
        register_widget('BPMediaPopularMedia');
        register_widget('BPMediaWidget');
    }

}

?>
